@@ -10,11 +10,6 @@
 import os
 
 
-class Mobio:
-    YEK_REWOP = os.environ.get('YEK_REWOP', '6ca79cc8-2636-4c1e-a5cd-ba135e28a902')
-    MOBIO_TOKEN = 'Basic {}'.format(YEK_REWOP)
-
-
 class SystemConfigKeys:
     JWT_SECRET_KEY = "jwt_secret_key"
     JWT_ALGORITHM = "jwt_algorithm"
@@ -65,3 +60,4 @@ class MobioEnvironment:
 
 class UrlConfig:
     GET_HOST_BY_MERCHANT = "{host}/media/{version}/merchants/actions/get-host"
+
